@@ -1,5 +1,4 @@
 from Bio import SeqIO
-from Bio.Alphabet import generic_dna
 from Bio.Seq import Seq
 from Bio.SeqRecord import SeqRecord
 from collections import defaultdict
@@ -133,7 +132,6 @@ def agp_to_fasta(contigs_sequence_dict, agp_path, output_file):
                     scaffolds_sequence_dict[scaffold_name] += str(
                         Seq(
                             contigs_sequence_dict[contig_name][contig_start:contig_end],
-                            generic_dna,
                         ).reverse_complement()
                     )
 
@@ -146,5 +144,5 @@ def agp_to_fasta(contigs_sequence_dict, agp_path, output_file):
     )
     with open(output_file, "w") as out:
         for scaffold, sequence in sorted_scaffolds:
-            record = SeqRecord(Seq(sequence, generic_dna), id=scaffold, description='')
+            record = SeqRecord(Seq(sequence), id=scaffold, description='')
             out.write(record.format("fasta"))
